<?php
    class SimplePay {
        public $checkout_id,$checkout;
        public $name,$commission=true;
        public $simplePayConfig,$config=[],$lang=[],$page_type = "in-page",$callback_type="server-sided";
        public $payform=false;

        function __construct(){
            $this->config     = Modules::Config("Payment",__CLASS__);
            $this->lang       = Modules::Lang("Payment",__CLASS__);
            $this->name       = __CLASS__;
            $this->payform   = __DIR__.DS."pages".DS."payform";
          	$this->simplePayConfig = [
            	'HUF_MERCHANT' => $this->config["settings"]["huf-merchant"],          
                'HUF_SECRET_KEY' => $this->config["settings"]["huf-secret-key"],           
                'SANDBOX' => $this->config["settings"]["sandbox"],
                'URL' => '',
                'GET_DATA' => (isset($_GET['r']) && isset($_GET['s'])) ? ['r' => $_GET['r'], 's' => $_GET['s']] : [],
                'POST_DATA' => $_POST,
                'SERVER_DATA' => $_SERVER,
                'LOGGER' => true,                             
                'LOG_PATH' => 'log',                          
                'AUTOCHALLENGE' => true
            ];
        }

        public function get_auth_token(){
            $syskey = Config::get("crypt/system");
            $token  = md5(Crypt::encode("SimplePay-Auth-Token=".$syskey,$syskey));
            return $token;
        }

        public function set_checkout($checkout){
            $this->checkout_id = $checkout["id"];
            $this->checkout    = $checkout;
        }

        public function commission_fee_calculator($amount){
            $rate = $this->get_commission_rate();
            if(!$rate) return 0;
            $calculate = Money::get_discount_amount($amount,$rate);
            return $calculate;
        }


        public function get_commission_rate(){
            return $this->config["settings"]["commission_rate"];
        }

        public function cid_convert_code($id=0){
            Helper::Load("Money");
            $currency   = Money::Currency($id);
            if($currency) return $currency["code"];
            return false;
        }

        public function get_ip(){
            return UserManager::GetIP();
        }
      
      	public function get_config_data(){
            $data = [
            	'merchant_id' => $this->config["settings"]["huf-merchant"],
              	'secret_key' => $this->config["settings"]["huf-secret-key"],
              	'sandbox' => $this->config["settings"]["sandbox"]             
            ];
            return $data;
        }	
      
        public function payment_result(){          
            header('Content-Type: application/json; charset=utf-8');
          	
            require_once 'src/SimplePayV21.php';

            $json = file_get_contents('php://input');

            $input = (array) json_decode($json);

            $trx = new SimplePayIpn;

            $trx->addConfig($this->simplePayConfig);

            //check signature and confirm IPN
            //-----------------------------------------------------------------------------------------
            if ($trx->isIpnSignatureCheck($json)) {
                
                $trx->runIpnConfirm();
				$confirm = $trx->getIpnConfirmContent();               
				switch($input["status"]) {
                	case 'CANCELLED':
                    	return [
                            'status' => "ERROR",
                            'status_msg' => Bootstrap::$lang->get("errors/error6",Config::get("general/local")),
                        ];
                    	break;
                    case 'TIMEOUT':
                        return [
                            'status' => "ERROR",
                            'status_msg' => Bootstrap::$lang->get("errors/error6",Config::get("general/local")),
                        ];
                    	break;
                    case 'NOTAUTHORIZED':
                        return [
                            'status' => "ERROR",
                            'status_msg' => Bootstrap::$lang->get("errors/error6",Config::get("general/local")),                         
                        ];
                    	break;                   
                }
            
                $checkout_id        = $input["orderRef"];
                $checkout           = Basket::get_checkout($checkout_id);

                if(!$checkout) {
                      return [
                          'status' => "ERROR",
                          'status_msg' => Bootstrap::$lang->get("errors/error6",Config::get("general/local")),                          
                      ];               
                }           
				
              	if($input["status"] == "FINISHED") {
                    $this->set_checkout($checkout);
                    Basket::set_checkout($checkout["id"],['status' => "paid"]);

                    return [
                        'status'         => "SUCCESS",
                        'checkout'       => $checkout,
                    ];

                } else [
                  	'checkout' => $checkout,
                    'status' => "ERROR",
                    'status_msg' => Bootstrap::$lang->get("errors/error6",Config::get("general/local")),                    
                	];
              
            	}
      	  } 
    }